==> server-api-impl-10.2.0-622.1445-sources.jar: com/xebialabs/deployit/core/rest/json/ActiveUserSessionJsonWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.xebialabs.deployit.core.api.dto.ActiveUserSession;
import com.xebialabs.deployit.core.converters.SessionsConverter;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.util.Collection;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class ActiveUserSessionJsonWriter implements MessageBodyWriter<Collection<ActiveUserSession>> {

    private final SessionsConverter converter = new SessionsConverter();
    private final JsonWriterHelper helper = new JsonWriterHelper();


    @Override
    public boolean isWriteable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        if (!mediaType.toString().contains(MediaType.APPLICATION_JSON)) {
            return false;
        }

        return ActiveUserSession.class.isAssignableFrom(helper.getType(type, genericType));
    }


    @Override
    public long getSize(Collection<ActiveUserSession> session, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return -1L;
    }


    @Override
    public void writeTo(Collection<ActiveUserSession> sessions, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(converter.toJson(sessions).getBytes());
    }
}

==> server-api-impl-10.4.0-1111.1103-sources.jar: com/xebialabs/deployit/core/rest/json/ActiveUserSessionJsonWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import ai.digital.deploy.sql.model.ActiveUserSession;
import com.xebialabs.deployit.core.converters.SessionsConverter;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.OutputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.util.Collection;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class ActiveUserSessionJsonWriter implements MessageBodyWriter<Collection<ActiveUserSession>> {

    private final SessionsConverter converter = new SessionsConverter();
    private final JsonWriterHelper helper = new JsonWriterHelper();


    @Override
    public boolean isWriteable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        if (!mediaType.toString().contains(MediaType.APPLICATION_JSON)) {
            return false;
        }

        return ActiveUserSession.class.isAssignableFrom(helper.getType(type, genericType));
    }


    @Override
    public long getSize(Collection<ActiveUserSession> session, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return -1L;
    }


    @Override
    public void writeTo(Collection<ActiveUserSession> sessions, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(converter.toJson(sessions).getBytes());
    }
}
